Module with configuration which reflects BridgeHubWococo runtime setup (AccountId, Headers, Hashes…)
Structs
- Account
Info Storage MapKey Provider - Provides a storage key for account data.
- Block
Execution Weight - Importing a block with 0 Extrinsics.
- Block
Length - Block
Weights - Bridge
HubWococo - BridgeHubWococo parachain.
- Extrinsic
Base Weight - Executing a NO-OP
System::remarksExtrinsic. - Perbill
- A fixed point representation of a number in the range [0, 1].
Constants
- AVERAGE_
BLOCK_ INTERVAL - Average block interval in Cumulus-based parachains.
- AVERAGE_
ON_ INITIALIZE_ RATIO - All cumulus bridge hubs assume that about 5 percent of the block weight is consumed by
on_initializehandlers. This is used to limit the maximal weight of a single extrinsic. - BEST_
FINALIZED_ BRIDGE_ HUB_ WOCOCO_ HEADER_ METHOD - Name of the
<ThisChain>FinalityApi::best_finalizedruntime method. - BRIDGE_
HUB_ WOCOCO_ PARACHAIN_ ID - Identifier of BridgeHubWococo in the Wococo relay chain.
- EXTRA_
STORAGE_ PROOF_ SIZE - Number of extra bytes (excluding size of storage value itself) of storage proof, built at Polkadot-like chain. This mostly depends on number of entries in the storage trie. Some reserve is reserved to account future chain growth.
- FROM_
BRIDGE_ HUB_ WOCOCO_ MESSAGE_ DETAILS_ METHOD - Name of the
From<ThisChain>InboundLaneApi::message_detailsruntime method. - MAX_
UNCONFIRMED_ MESSAGES_ IN_ CONFIRMATION_ TX - Maximal number of unconfirmed messages at inbound lane for Cumulus-based parachains. Note: this value is security-relevant, decreasing it should not be done without careful analysis (like the one above).
- MAX_
UNREWARDED_ RELAYERS_ IN_ CONFIRMATION_ TX - Maximal number of unrewarded relayer entries at inbound lane for Cumulus-based parachains. Note: this value is security-relevant, decreasing it should not be done without careful analysis (like the one above).
- NORMAL_
DISPATCH_ RATIO - All cumulus bridge hubs allow normal extrinsics to fill block up to 75 percent.
- TO_
BRIDGE_ HUB_ WOCOCO_ MESSAGE_ DETAILS_ METHOD - Name of the
To<ThisChain>OutboundLaneApi::message_detailsruntime method. - TX_
EXTRA_ BYTES - Maximal number of bytes, included in the signed Polkadot-like transaction apart from the encoded call itself.
- WITH_
BRIDGE_ HUB_ ROCOCO_ TO_ WOCOCO_ MESSAGES_ PALLET_ NAME - Name of the With-BridgeHubWococo messages pallet instance that is deployed at bridged chains.
- WITH_
BRIDGE_ HUB_ WOCOCO_ RELAYERS_ PALLET_ NAME - Name of the With-BridgeHubWococo bridge-relayers pallet instance that is deployed at bridged chains.
- WITH_
BRIDGE_ WOCOCO_ TO_ ROCOCO_ MESSAGES_ PALLET_ INDEX - Pallet index of
BridgeWococoToRococoMessages: pallet_bridge_messages::<Instance2>.
Traits
- Bridge
HubWococo Finality Api - API for querying information about the finalized chain headers.
- From
Bridge HubWococo Inbound Lane Api - Inbound message lane API for messages sent by this chain.
- ToBridge
HubWococo Outbound Lane Api - Outbound message lane API for messages that are sent to this chain.
Type Aliases
- Account
Id - Id of account on Polkadot-like chains.
- Account
Public - Public key of account on Polkadot-like chains.
- Account
Signer - Public key of the chain account that may be used to verify signatures.
- Address
- The address format for describing accounts.
- Balance
- The balance of an account on Polkadot-like chain.
- Block
Number - Block number type used in Polkadot-like chains.
- Hash
- Hash type used in Polkadot-like chains.
- Hasher
- The type of object that can produce hashes on Polkadot-like chains.
- Hashing
- Hashing type.
- Header
- The header type used by Polkadot-like chains.
- Nonce
- Nonce of a transaction on the Polkadot-like chains.
- Signature
- Signature type used by Polkadot-like chains.
- Signed
Block - Polkadot-like block signed with a Justification.
- Signed
Extension - Signed extension that is used by all bridge hubs.
- Unchecked
Extrinsic - Unchecked Extrinsic type.